function [H0, H1, bestd] = ApproxRAP (A0, A1, Lags, numOfMoms, sumOrders)

moms = MarginalMomentsFromRAP (A0, A1, numOfMoms);
alA = DRPSolve(inv(-A0)*A1);

% obtain a set of PH distributions
phs = mommatch(moms, (numOfMoms+1)/2:sumOrders);

% go over the obtained PH distributions, fit the correlations, and select
% the best
bestd = inf;
for ph=phs    
    B0 = ph.A;
    if Lags>0
        [B1, d] = OptimDist (A0,A1,alA,B0,real(ph.alpha),Lags);
    else
        % run optimization multiple times and select best solution
        d = inf;
        for i=1:50
            [X, acfd] = OptimDistAcf (A0,A1,alA,B0,real(ph.alpha));
            if acfd>0 && acfd<d
                B1 = X;
                d = acfd;
            end
        end        
    end
    d
    if d<bestd
        H0 = B0;
        H1 = B1;
        bestd = d;
    end
end

end

