function PaperExample2 ()

global BuToolsCheckInput
BuToolsCheckInput = false;

% Arrival process
% mean: 0.48647
% cv2: 2.4789
% acf-1:  0.21062
D0 = [-0.542,	0.003, 	0; 0.04,	-0.23,	0.01; 0,	0.001,	-2.269];
D1 = [0.021	0	0.518; 0	0.17	0.01; 0.004	0.005	2.259];

% Service process
% mean: 0.30366
% cv2: 4.0917
% acf-1: 0.112
S0 = [-10 0; 0 -2.22];
S1 = [7.5 2.5; 0.4 1.82];

% Queue utilization:  0.62421

% Method 1a: ETAQA model truncated at k=1
[G0, G1] = ETAQADepModel(D0,D1,S0,S1,2);
[alpha,A] = MAPMAP1QLD(G0,G1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3)
%        2.3379       12.909       102.24

% Method 1b: Approx. ETAQA model with 2 states and lag-1 only
[F0, F1] = ApproxRAP (G0, G1, 1, 3, 6);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%        2.4266       14.677       131.55
% The result is the same if more than one lags are optimized
% For acf optimized:    2.2921       12.893       107.05 (d= 0.014537)

% Method 1c: Approx. ETAQA model with 3 states and lag-1 only
[F0, F1] = ApproxRAP (G0, G1, 1, 5, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.5722       16.774        162.8
% 2 lags:   2.408       14.548       130.75
% 5 lags:   2.4277       14.878          136
% 8 lags:   2.4329       14.966       137.42

% Method 2a: ETAQA model truncated at k=5
[G0, G1] = ETAQADepModel(D0,D1,S0,S1,6);
[alpha,A] = MAPMAP1QLD(G0,G1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3)
%       2.5405       15.586       134.55

% Method 2b: Approx. ETAQA model with 2 states and lag-1 only
[F0, F1] = ApproxRAP (G0, G1, 1, 3, 6);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4266       14.677       131.55

% Method 2c: Approx. ETAQA model with 3 states and lag-1 only
[F0, F1] = ApproxRAP (G0, G1, 1, 5, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4266       14.677       131.55

% Method 2d: Approx. ETAQA model with 2 states and lag-5
[F0, F1] = ApproxRAP (G0, G1, 5, 3, 6);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4266       14.677       131.55

% Method 2e: Approx. ETAQA model with 3 states and lag-5
[F0, F1] = ApproxRAP (G0, G1, 5, 5, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.6805        18.55       192.16

% Method 3a: Joint moment based, with 3 moments
M = 2;
moms = MarginalMomentsFromRAP(G0, G1, 2*M-1);
Nm = LagkJointMomentsFromRAP(G0, G1, M-1);
[H0, H1] = RAPFromMoments(moms, Nm);
[alpha,A] = MAPMAP1QLD(H0,H1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) % Markovian representation exists!
%       2.3255       13.325       112.82

% Method 3b: Approx. joint moment matching model with 2 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 3, 6);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.3255       13.325       112.82

% Method 4a: Joint moment based, with 4 moments
M = 3;
moms = MarginalMomentsFromRAP(G0, G1, 2*M-1);
Nm = LagkJointMomentsFromRAP(G0, G1, M-1);
[H0, H1] = RAPFromMoments(moms, Nm);
[alpha,A] = MAPMAP1QLD(H0,H1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%        2.755       20.225       225.53

% Method 4b: Approx. joint moment matching model with 2 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 3, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4266       14.677       131.55

% Method 4c: Approx. joint moment matching model with 3 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 5, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.7489       20.158       224.72

% Method 5a: Joint moment based, with 7 moments
M = 4;
moms = MarginalMomentsFromRAP(G0, G1, 2*M-1);
Nm = LagkJointMomentsFromRAP(G0, G1, M-1);
[H0, H1] = RAPFromMoments(moms, Nm);
[alpha,A] = MAPMAP1QLD(H0,H1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) % no valid Markovian representation!
%      2.7837       20.757       235.37

% Method 5b: Approx. joint moment matching model with 2 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 3, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4266       14.677       131.55

% Method 5c: Approx. joint moment matching model with 3 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 5, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.7326       19.898       220.28

% Method 5d: Approx. joint moment matching model with 4 states and lag-1 only
[F0, F1] = ApproxRAP (H0, H1, 1, 7, 7);
[alpha,A] = MAPMAP1QLD(F0,F1,[-6 6; 0 -6],[0 0; 6 0]);
qlm = MomentsFromMG(alpha, A, 3) 
%       2.4449       15.171       140.78


% exact queue length moments:
%       2.6592       18.086       181.53


end

